{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "BLAT",
            "doc": "fast sequence search command line tool\n>blat -fastMap -t dna -q rna -out blast8 <database> <query> <output>\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "blat.log",
            "stderr": "blat.error",
            "inputs": [
                {
                    "type": "File",
                    "doc": "Database fasta format file",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#blat.tool.cwl/database"
                },
                {
                    "type": "string",
                    "doc": "Database type",
                    "inputBinding": {
                        "prefix": "-t=",
                        "separate": false
                    },
                    "id": "#blat.tool.cwl/dbType"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Run for fast DNA/DNA remapping - not allowing introns",
                    "inputBinding": {
                        "prefix": "-fastMap"
                    },
                    "id": "#blat.tool.cwl/fastMap"
                },
                {
                    "type": "string",
                    "doc": "Output name",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#blat.tool.cwl/outName"
                },
                {
                    "type": "File",
                    "doc": "Query fasta format file",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#blat.tool.cwl/query"
                },
                {
                    "type": "string",
                    "doc": "Query type",
                    "inputBinding": {
                        "prefix": "-q=",
                        "separate": false
                    },
                    "id": "#blat.tool.cwl/queryType"
                }
            ],
            "baseCommand": [
                "blat"
            ],
            "arguments": [
                "-out=blast8"
            ],
            "id": "#blat.tool.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#blat.tool.cwl/error",
                    "outputBinding": {
                        "glob": "blat.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#blat.tool.cwl/info",
                    "outputBinding": {
                        "glob": "blat.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output tab separated similarity file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#blat.tool.cwl/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "bleachsims",
            "doc": "filter similarity file by E-value and number of hits\n>bleachsims -s <input> -o <output> -m 20 -r 0 -c 3\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "bleachsims.log",
            "stderr": "bleachsims.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Remove all evalues with an exponent lower than cutoff, default 3",
                    "default": 3,
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#bleachsims.tool.cwl/cutoff"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "only apply cutoff filter",
                    "inputBinding": {
                        "prefix": "--eval_only"
                    },
                    "id": "#bleachsims.tool.cwl/cutoffOnly"
                },
                {
                    "type": "File",
                    "doc": "Input similarity blast-m8 file",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#bleachsims.tool.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Minimum number of hits per query, default 20",
                    "default": 20,
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#bleachsims.tool.cwl/min"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "only apply cutoff filter",
                    "inputBinding": {
                        "prefix": "--min_hit_only"
                    },
                    "id": "#bleachsims.tool.cwl/minHitOnly"
                },
                {
                    "type": "string",
                    "doc": "Output name",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#bleachsims.tool.cwl/outName"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Best evalue plus this exponent that will be returned, default 0 (no range)",
                    "default": 0,
                    "inputBinding": {
                        "prefix": "-r"
                    },
                    "id": "#bleachsims.tool.cwl/range"
                }
            ],
            "baseCommand": [
                "bleachsims"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bleachsims.tool.cwl/error",
                    "outputBinding": {
                        "glob": "bleachsims.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#bleachsims.tool.cwl/info",
                    "outputBinding": {
                        "glob": "bleachsims.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output filtered similarity blast-m8 file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#bleachsims.tool.cwl/output"
                }
            ],
            "id": "#bleachsims.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "CD-HIT-est",
            "doc": "cluster nucleotide sequences\nuse max available cpus and memory\n>cdhit-est -n 9 -d 0 -T 0 -M 0 -c 0.97 -i <input> -o <output>\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "cdhit-est.log",
            "stderr": "cdhit-est.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "Percent identity threshold, default 0.97",
                    "default": 0.97,
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#cdhit-est.tool.cwl/identity"
                },
                {
                    "type": "File",
                    "doc": "Input fasta format file",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#cdhit-est.tool.cwl/input"
                },
                {
                    "type": "string",
                    "doc": "Output name",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#cdhit-est.tool.cwl/outName"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Word length, default 9",
                    "default": 9,
                    "inputBinding": {
                        "prefix": "-n"
                    },
                    "id": "#cdhit-est.tool.cwl/word"
                }
            ],
            "baseCommand": [
                "cdhit-est"
            ],
            "arguments": [
                {
                    "prefix": "-M",
                    "valueFrom": "0"
                },
                {
                    "prefix": "-T",
                    "valueFrom": "0"
                },
                {
                    "prefix": "-d",
                    "valueFrom": "0"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#cdhit-est.tool.cwl/error",
                    "outputBinding": {
                        "glob": "cdhit-est.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#cdhit-est.tool.cwl/info",
                    "outputBinding": {
                        "glob": "cdhit-est.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output cluster mapping file",
                    "outputBinding": {
                        "glob": "$(inputs.outName).clstr"
                    },
                    "id": "#cdhit-est.tool.cwl/outClstr"
                },
                {
                    "type": "File",
                    "doc": "Output fasta format file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#cdhit-est.tool.cwl/outSeq"
                }
            ],
            "id": "#cdhit-est.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "cluster file reformat",
            "doc": "re-formats cd-hit .clstr file into mg-rast .mapping file\n>format_cluster.pl --input <input> --output <output>\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "format_cluster.log",
            "stderr": "format_cluster.error",
            "inputs": [
                {
                    "type": "File",
                    "doc": "Input .clstr format file",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#format_cluster.tool.cwl/input"
                },
                {
                    "type": "string",
                    "doc": "Output .mapping format file",
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "id": "#format_cluster.tool.cwl/outName"
                }
            ],
            "baseCommand": [
                "format_cluster.pl"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#format_cluster.tool.cwl/error",
                    "outputBinding": {
                        "glob": "format_cluster.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#format_cluster.tool.cwl/info",
                    "outputBinding": {
                        "glob": "format_cluster.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output .mapping format file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#format_cluster.tool.cwl/output"
                }
            ],
            "id": "#format_cluster.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "rna features",
            "doc": "identify rRNAs features from given rRNA fasta and blast aligned files\n>rna_feature.pl --seq <sequence> --sim <aligned> --ident 75 --output <output>\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "rna_feature.log",
            "stderr": "rna_feature.error",
            "inputs": [
                {
                    "type": "File",
                    "doc": "Tab separated similarity file",
                    "inputBinding": {
                        "prefix": "--sim"
                    },
                    "id": "#rna_feature.tool.cwl/aligned"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Percent identity threshold, default 75",
                    "default": 75,
                    "inputBinding": {
                        "prefix": "--ident"
                    },
                    "id": "#rna_feature.tool.cwl/identity"
                },
                {
                    "type": "string",
                    "doc": "Output fasta format file",
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "id": "#rna_feature.tool.cwl/outName"
                },
                {
                    "type": "File",
                    "doc": "Tab separated sequence file",
                    "inputBinding": {
                        "prefix": "--seq"
                    },
                    "id": "#rna_feature.tool.cwl/sequence"
                }
            ],
            "baseCommand": [
                "rna_feature.pl"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#rna_feature.tool.cwl/error",
                    "outputBinding": {
                        "glob": "rna_feature.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#rna_feature.tool.cwl/info",
                    "outputBinding": {
                        "glob": "rna_feature.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output fasta format file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#rna_feature.tool.cwl/output"
                }
            ],
            "id": "#rna_feature.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "seqUtil",
            "doc": "Utility tool for various sequence file transformations.\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "seqUtil.log",
            "stderr": "seqUtil.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Return fasta with each sequence truncated to 1024 bps",
                    "inputBinding": {
                        "prefix": "--bowtie_truncate"
                    },
                    "id": "#seqUtil.tool.cwl/bowtieTruncate"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Transform fasta to tabbed",
                    "inputBinding": {
                        "prefix": "--fasta2tab"
                    },
                    "id": "#seqUtil.tool.cwl/fasta2tab"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Transform fastq to fasta",
                    "inputBinding": {
                        "prefix": "--fastq2fasta"
                    },
                    "id": "#seqUtil.tool.cwl/fastq2fasta"
                },
                {
                    "type": "string",
                    "doc": "Output sequence file",
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "id": "#seqUtil.tool.cwl/output"
                },
                {
                    "type": "File",
                    "doc": "Input sequence file",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#seqUtil.tool.cwl/sequences"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Sort fasta file by ID",
                    "inputBinding": {
                        "prefix": "--sortbyid"
                    },
                    "id": "#seqUtil.tool.cwl/sortbyid"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Transform fasta to ID list, sorted by ID",
                    "inputBinding": {
                        "prefix": "--sortbyid2id"
                    },
                    "id": "#seqUtil.tool.cwl/sortbyid2id"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Transform fasta to tabbed, sorted by ID",
                    "inputBinding": {
                        "prefix": "--sortbyid2tab"
                    },
                    "id": "#seqUtil.tool.cwl/sortbyid2tab"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "List of sequences to subset input by, required with subsetSeqs option",
                    "inputBinding": {
                        "prefix": "--list"
                    },
                    "id": "#seqUtil.tool.cwl/subsetList"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Return fasta with each sequence truncated to 1024 bps",
                    "inputBinding": {
                        "prefix": "--subset_seqs"
                    },
                    "id": "#seqUtil.tool.cwl/subsetSeqs"
                }
            ],
            "baseCommand": [
                "seqUtil"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#seqUtil.tool.cwl/error",
                    "outputBinding": {
                        "glob": "seqUtil.error"
                    }
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#seqUtil.tool.cwl/file"
                },
                {
                    "type": "File",
                    "id": "#seqUtil.tool.cwl/info",
                    "outputBinding": {
                        "glob": "seqUtil.log"
                    }
                }
            ],
            "id": "#seqUtil.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "annotate sims",
            "doc": "create expanded annotated sims files from input md5 sim file and m5nr db\nsims_annotate.pl --verbose --in_sim <input> --in_scg <scgs> --ann_file <database> --format <seqFormat> --out_filter <outFilter> --out_expand <outExpand> -out_lca <outLca> --frag_num 5000\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "sims_annotate.log",
            "stderr": "sims_annotate.error",
            "inputs": [
                {
                    "type": "File",
                    "doc": "BerkelyDB of condensed M5NR",
                    "inputBinding": {
                        "prefix": "--ann_file"
                    },
                    "id": "#sims_annotate.tool.cwl/database"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Number of fragment chunks to load in memory at once before processing, default 5000",
                    "default": 5000,
                    "inputBinding": {
                        "prefix": "--frag_num"
                    },
                    "id": "#sims_annotate.tool.cwl/fragNum"
                },
                {
                    "type": "File",
                    "doc": "Input similarity blast-m8 file",
                    "inputBinding": {
                        "prefix": "--in_sim"
                    },
                    "id": "#sims_annotate.tool.cwl/input"
                },
                {
                    "type": "string",
                    "doc": "Output expanded protein sim file (protein mode only)",
                    "inputBinding": {
                        "prefix": "--out_expand"
                    },
                    "id": "#sims_annotate.tool.cwl/outExpandName"
                },
                {
                    "type": "string",
                    "doc": "Output filtered sim file",
                    "inputBinding": {
                        "prefix": "--out_filter"
                    },
                    "id": "#sims_annotate.tool.cwl/outFilterName"
                },
                {
                    "type": "string",
                    "doc": "Output expanded LCA file (protein and rna mode)",
                    "inputBinding": {
                        "prefix": "--out_lca"
                    },
                    "id": "#sims_annotate.tool.cwl/outLcaName"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "md5 single copy gene file",
                    "inputBinding": {
                        "prefix": "--in_scg"
                    },
                    "id": "#sims_annotate.tool.cwl/scgs"
                },
                {
                    "type": "string",
                    "doc": "Type of sequences data in input file, rna or protein",
                    "default": "protein",
                    "inputBinding": {
                        "prefix": "--format"
                    },
                    "id": "#sims_annotate.tool.cwl/seqFormat"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Verbose logging mode",
                    "inputBinding": {
                        "prefix": "--verbose"
                    },
                    "id": "#sims_annotate.tool.cwl/verbose"
                }
            ],
            "baseCommand": [
                "sims_annotate.pl"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#sims_annotate.tool.cwl/error",
                    "outputBinding": {
                        "glob": "sims_annotate.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#sims_annotate.tool.cwl/info",
                    "outputBinding": {
                        "glob": "sims_annotate.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output expanded sim file",
                    "outputBinding": {
                        "glob": "$(inputs.outExpandName)"
                    },
                    "id": "#sims_annotate.tool.cwl/outExpand"
                },
                {
                    "type": "File",
                    "doc": "Output filtered similarity file",
                    "outputBinding": {
                        "glob": "$(inputs.outFilterName)"
                    },
                    "id": "#sims_annotate.tool.cwl/outFilter"
                },
                {
                    "type": "File",
                    "doc": "Output expanded LCA file",
                    "outputBinding": {
                        "glob": "$(inputs.outLcaName)"
                    },
                    "id": "#sims_annotate.tool.cwl/outLca"
                }
            ],
            "id": "#sims_annotate.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "GNU sort",
            "doc": "sort text file base on given field(s)",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "sort.log",
            "stderr": "sort.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "use SEP instead of non-blank to blank transition, default is tab",
                    "inputBinding": {
                        "prefix": "-t",
                        "valueFrom": "$(\"\\u0009\")"
                    },
                    "id": "#sort.tool.cwl/field"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "Files to sort",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#sort.tool.cwl/input"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-k"
                        }
                    },
                    "doc": "start a key at POS1, end it at POS2 (origin 1)",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#sort.tool.cwl/key"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "merge only, the input files are assumed to be pre-sorted",
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#sort.tool.cwl/merge"
                },
                {
                    "type": "string",
                    "doc": "write result to FILE instead of standard output",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#sort.tool.cwl/outName"
                }
            ],
            "baseCommand": [
                "sort"
            ],
            "arguments": [
                {
                    "prefix": "-T",
                    "valueFrom": "$(runtime.tmpdir)"
                },
                {
                    "prefix": "-S",
                    "valueFrom": "$(runtime.ram)M"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#sort.tool.cwl/error",
                    "outputBinding": {
                        "glob": "sort.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#sort.tool.cwl/info",
                    "outputBinding": {
                        "glob": "sort.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "The sorted file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#sort.tool.cwl/output"
                }
            ],
            "id": "#sort.tool.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "sortmerna",
            "doc": "align rRNA fasta file against clustered rRNA index\noutput in blast m8 format\n>sortmerna -a <# core> -m <MB ram> -e 0.1 --blast '1 cigar qcov qstrand' --ref '<refFasta>,<indexDir>/<indexName>' --reads <input> --aligned <input basename>\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "sortmerna.log",
            "stderr": "sortmerna.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "E-value threshold, default 0.1",
                    "default": 0.1,
                    "inputBinding": {
                        "prefix": "-e"
                    },
                    "id": "#sortmerna.tool.cwl/evalue"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "doc": "Directory containing index files with prefix INDEXNAME",
                    "default": "./",
                    "id": "#sortmerna.tool.cwl/indexDir"
                },
                {
                    "type": "string",
                    "doc": "Prefix for index files",
                    "id": "#sortmerna.tool.cwl/indexName"
                },
                {
                    "type": "File",
                    "doc": "Input file, sequence (fasta/fastq)",
                    "inputBinding": {
                        "prefix": "--reads"
                    },
                    "id": "#sortmerna.tool.cwl/input"
                },
                {
                    "type": "File",
                    "doc": "Reference .fasta file",
                    "id": "#sortmerna.tool.cwl/refFasta"
                }
            ],
            "baseCommand": [
                "sortmerna"
            ],
            "arguments": [
                {
                    "prefix": "--blast",
                    "valueFrom": "1 cigar qcov qstrand"
                },
                {
                    "prefix": "-a",
                    "valueFrom": "$(runtime.cores)"
                },
                {
                    "prefix": "--ref",
                    "valueFrom": "$(inputs.refFasta.path),$(inputs.indexDir.path)/$(inputs.indexName)"
                },
                {
                    "prefix": "--aligned",
                    "valueFrom": "$(inputs.input.basename)"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#sortmerna.tool.cwl/error",
                    "outputBinding": {
                        "glob": "sortmerna.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#sortmerna.tool.cwl/info",
                    "outputBinding": {
                        "glob": "sortmerna.log"
                    }
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "Output tab separated aligned file",
                    "outputBinding": {
                        "glob": [
                            "$(inputs.input.basename).blast"
                        ]
                    },
                    "id": "#sortmerna.tool.cwl/output"
                }
            ],
            "id": "#sortmerna.tool.cwl"
        },
        {
            "class": "Workflow",
            "label": "rna annotation",
            "doc": "RNAs - predict, cluster, identify, annotate",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/jobid"
                },
                {
                    "type": "File",
                    "id": "#main/m5nrBDB"
                },
                {
                    "type": "File",
                    "id": "#main/m5rnaClust"
                },
                {
                    "type": "File",
                    "id": "#main/m5rnaFull"
                },
                {
                    "type": "Directory",
                    "id": "#main/m5rnaIndex"
                },
                {
                    "type": "string",
                    "id": "#main/m5rnaPrefix"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.97,
                    "id": "#main/rnaIdentity"
                },
                {
                    "type": "File",
                    "id": "#main/sequences"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/formatCluster/output",
                    "id": "#main/rnaClustMapOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rnaCluster/outSeq",
                    "id": "#main/rnaClustSeqOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/annotateSims/outExpand",
                    "id": "#main/rnaExpandOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rnaFeature/output",
                    "id": "#main/rnaFeatureOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/annotateSims/outFilter",
                    "id": "#main/rnaFilterOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/annotateSims/outLca",
                    "id": "#main/rnaLCAOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/bleachSims/output",
                    "id": "#main/rnaSimsOut"
                }
            ],
            "steps": [
                {
                    "run": "#sims_annotate.tool.cwl",
                    "in": [
                        {
                            "source": "#main/m5nrBDB",
                            "id": "#main/annotateSims/database"
                        },
                        {
                            "source": "#main/bleachSims/output",
                            "id": "#main/annotateSims/input"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).450.rna.expand.rna",
                            "id": "#main/annotateSims/outExpandName"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).450.rna.sims.filter",
                            "id": "#main/annotateSims/outFilterName"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).450.rna.expand.lca",
                            "id": "#main/annotateSims/outLcaName"
                        },
                        {
                            "valueFrom": "rna",
                            "id": "#main/annotateSims/seqFormat"
                        }
                    ],
                    "out": [
                        "#main/annotateSims/outFilter",
                        "#main/annotateSims/outExpand",
                        "#main/annotateSims/outLca"
                    ],
                    "id": "#main/annotateSims"
                },
                {
                    "run": "#bleachsims.tool.cwl",
                    "in": [
                        {
                            "source": "#main/rnaBlat/output",
                            "id": "#main/bleachSims/input"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).450.rna.sims",
                            "id": "#main/bleachSims/outName"
                        }
                    ],
                    "out": [
                        "#main/bleachSims/output"
                    ],
                    "id": "#main/bleachSims"
                },
                {
                    "run": "#format_cluster.tool.cwl",
                    "in": [
                        {
                            "source": "#main/rnaCluster/outClstr",
                            "id": "#main/formatCluster/input"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).440.cluster.rna97.mapping",
                            "id": "#main/formatCluster/outName"
                        }
                    ],
                    "out": [
                        "#main/formatCluster/output"
                    ],
                    "id": "#main/formatCluster"
                },
                {
                    "run": "#blat.tool.cwl",
                    "in": [
                        {
                            "source": "#main/m5rnaFull",
                            "id": "#main/rnaBlat/database"
                        },
                        {
                            "valueFrom": "dna",
                            "id": "#main/rnaBlat/dbType"
                        },
                        {
                            "default": true,
                            "id": "#main/rnaBlat/fastMap"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).450.rna.sims.full",
                            "id": "#main/rnaBlat/outName"
                        },
                        {
                            "source": "#main/rnaCluster/outSeq",
                            "id": "#main/rnaBlat/query"
                        },
                        {
                            "valueFrom": "rna",
                            "id": "#main/rnaBlat/queryType"
                        }
                    ],
                    "out": [
                        "#main/rnaBlat/output"
                    ],
                    "id": "#main/rnaBlat"
                },
                {
                    "run": "#cdhit-est.tool.cwl",
                    "in": [
                        {
                            "source": "#main/rnaIdentity",
                            "id": "#main/rnaCluster/identity"
                        },
                        {
                            "source": "#main/rnaFeature/output",
                            "id": "#main/rnaCluster/input"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).440.cluster.rna97.fna",
                            "id": "#main/rnaCluster/outName"
                        }
                    ],
                    "out": [
                        "#main/rnaCluster/outSeq",
                        "#main/rnaCluster/outClstr"
                    ],
                    "id": "#main/rnaCluster"
                },
                {
                    "run": "#rna_feature.tool.cwl",
                    "in": [
                        {
                            "source": "#main/sorttab/output",
                            "id": "#main/rnaFeature/aligned"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).425.search.rna.fna",
                            "id": "#main/rnaFeature/outName"
                        },
                        {
                            "source": "#main/sortseq/file",
                            "id": "#main/rnaFeature/sequence"
                        }
                    ],
                    "out": [
                        "#main/rnaFeature/output"
                    ],
                    "id": "#main/rnaFeature"
                },
                {
                    "run": "#sortmerna.tool.cwl",
                    "in": [
                        {
                            "source": "#main/m5rnaIndex",
                            "id": "#main/sortmerna/indexDir"
                        },
                        {
                            "source": "#main/m5rnaPrefix",
                            "id": "#main/sortmerna/indexName"
                        },
                        {
                            "source": "#main/sequences",
                            "id": "#main/sortmerna/input"
                        },
                        {
                            "source": "#main/m5rnaClust",
                            "id": "#main/sortmerna/refFasta"
                        }
                    ],
                    "out": [
                        "#main/sortmerna/output"
                    ],
                    "id": "#main/sortmerna"
                },
                {
                    "run": "#seqUtil.tool.cwl",
                    "in": [
                        {
                            "source": "#main/sequences",
                            "valueFrom": "$(self.basename).sort.tab",
                            "id": "#main/sortseq/output"
                        },
                        {
                            "source": "#main/sequences",
                            "id": "#main/sortseq/sequences"
                        },
                        {
                            "default": true,
                            "id": "#main/sortseq/sortbyid2tab"
                        }
                    ],
                    "out": [
                        "#main/sortseq/file"
                    ],
                    "id": "#main/sortseq"
                },
                {
                    "run": "#sort.tool.cwl",
                    "in": [
                        {
                            "source": "#main/sortmerna/output",
                            "id": "#main/sorttab/input"
                        },
                        {
                            "valueFrom": "$([\"1,1\"])",
                            "id": "#main/sorttab/key"
                        },
                        {
                            "source": "#main/sortmerna/output",
                            "valueFrom": "$(self[0].basename).sort",
                            "id": "#main/sorttab/outName"
                        }
                    ],
                    "out": [
                        "#main/sorttab/output"
                    ],
                    "id": "#main/sorttab"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
